@@ -1,6 +1,6 @@
 package Net::WebSocket;
 
-our $VERSION = '0.031';
+our $VERSION = '0.04';
 
 =encoding utf-8
 
@@ -65,9 +65,11 @@ the underlying transport mechanism is up to you: it could be a file,
 a UNIX socket, ordinary TCP/IP, some funky C<tie()>d object, or whatever.
 
 Net::WebSocket also “has no opinions” about how you should do I/O or HTTP
-headers. As a result of this “bare-bones” approach, Net::WebSocket can likely
+headers. There are too many different ways to accomplish HTTP header
+management in particular for it to be sensible for a WebSocket library to
+impose any one approach. As a result of this, Net::WebSocket can likely
 fit your project; however, it won’t absolve you of the need to know some
-things aboutthe WebSocket protocol itself. There are some examples
+things about the WebSocket protocol itself. There are some examples
 of how you might write complete applications (client or server)
 in the distribution’s C<demo/> directory.
 
@@ -159,9 +161,13 @@ Recall that in some languages—like JavaScript!—the difference between
 =head2 Use of L<IO::Framed>
 
 CPAN’s L<IO::Framed> provides a straightforward interface for chunking up
-data from byte streams into frames. You don’t have to use it (which is why
-it’s not listed as a requirement), but you’ll need to provide an equivalent
-interface if you don’t.
+data from byte streams into frames. It also provides a write buffer for
+non-blocking writes, and it retries on EINTR. You don’t have to use it
+(which is why it’s not listed as a requirement), but you’ll need to provide
+a compatible interface if you don’t.
+
+See the demo scripts that use L<IO::Framed> for an example of when you may
+need a different solution here.
 
 =head1 EXTENSION SUPPORT
 
@@ -172,7 +178,7 @@ protocol, all of which Net::WebSocket supports:
 
 =item * The three reserved bits in each frame’s header.
 (See L<Net::WebSocket::Frame>.) This is used, e.g., in the
-L<https://tools.ietf.org/html/rfc7692|permessage-deflate extension>.
+L<permessage-deflate extension|https://tools.ietf.org/html/rfc7692>.
 
 =item * Additional opcodes: 3-7 and 11-15. You’ll need to subclass
 L<Net::WebSocket::Frame> for this, and you will likely want to subclass
@@ -194,6 +200,9 @@ can do in your application.
 
 =over
 
+=item * Support the L<permessage-deflate|https://tools.ietf.org/html/rfc7692>
+extension natively.
+
 =item * Add tests, especially for extension support.
 
 =back
