@@ -4,8 +4,9 @@ use strict;
 use warnings;
 
 use Digest::SHA ();
+use Module::Load ();
 
-use constant WS_MAGIC_CONSTANT => '258EAFA5-E914-47DA-95CA-C5AB0DC85B11';
+use constant _WS_MAGIC_CONSTANT => '258EAFA5-E914-47DA-95CA-C5AB0DC85B11';
 
 sub create_header_text {
     my $self = shift;
@@ -20,7 +21,7 @@ sub _get_accept {
 
     $key_b64 =~ s<\A\s+|\s+\z><>g;
 
-    my $accept = Digest::SHA::sha1_base64( $key_b64 . WS_MAGIC_CONSTANT() );
+    my $accept = Digest::SHA::sha1_base64( $key_b64 . _WS_MAGIC_CONSTANT() );
 
     #pad base64
     $accept .= '=' x (4 - (length($accept) % 4));
@@ -37,4 +38,17 @@ sub _encode_subprotocols {
     );
 }
 
+sub _encode_extensions {
+    my ($self) = @_;
+
+    Module::Load::load('HTTP::Headers::Util');
+
+    return if !$self->{'extensions'};
+    return if !@{ $self->{'extensions'} };
+
+    my ($first, @others) = @{ $self->{'extensions'} };
+
+    return 'Sec-WebSocket-Extensions: ' . $first->to_string(@others);
+}
+
 1;
